<?php
require_once './../database.php';

/**
 * Represents a Mantenimiento object.
 *
 * This class is responsible for handling Mantenimiento data and operations.
 */
class Mantenimiento
{
    function __construct() {}

    /**
     * Retrieves all the records from the 'mantenimiento' table.
     *
     * @return array|false Returns an array of records if successful, false otherwise.
     */
    public static function getAll()
    {
        $query = "SELECT * FROM mantenimiento ORDER BY Mantenimiento_Id DESC";
        try {

            $cmd = Database::getInstance()->getDb()->prepare($query);

            $cmd->execute();

            return $cmd->fetchAll(PDO::FETCH_ASSOC);
        } catch (PDOException $e) {
            return false;
        }
    }

    /**
     * Retrieves all maintenance records associated with a specific tablet ID.
     *
     * @param int $id The ID of the tablet.
     * @return array|false An array of maintenance records if successful, false otherwise.
     */
    public static function getByTabletId($id)
    {
        $query = "SELECT * FROM mantenimiento WHERE id_tablet = ?";
        try {

            $cmd = Database::getInstance()->getDb()->prepare($query);
            $cmd->execute(array($id));

            return $cmd->fetchAll(PDO::FETCH_ASSOC);
        } catch (PDOException $e) {
            return false;
        }
    }

    /**
     * Retrieves the latest maintenance record for a given equipment asset.
     *
     * @param string $equipoActivoFijo The asset number of the equipment.
     * @return array|false The latest maintenance record as an associative array, or false if an error occurs.
     */
    public static function getLatestByEquipoActivoFijo($equipoActivoFijo)
    {
        $query = "SELECT * FROM mantenimiento M INNER JOIN equipos E ON M.nManEquipo_Id = E.Equipo_Id WHERE E.sEqActivoFijo = ? ORDER BY M.Mantenimiento_Id DESC LIMIT 1";
        try {

            $cmd = Database::getInstance()->getDb()->prepare($query);
            $cmd->execute(array($equipoActivoFijo));

            return $cmd->fetch(PDO::FETCH_ASSOC);
        } catch (PDOException $e) {
            return false;
        }
    }
}
