<?php

require_once './../helpers/ResponseHelper.php';

class Router
{
    private $routes = [];
    private $basePath;

    public function __construct($basePath)
    {
        $this->basePath = rtrim($basePath, '/');
    }

    public function register($method, $route, $action)
    {
        $method = strtoupper($method);

        // $routeParts = explode("/", $route);
        // $endRoutePart = end($routeParts);
        // $hasParam = $endRoutePart == "{param}";

        // $this->routes[$method][$route] = ["action" => $action, "hasParam" => $hasParam];
        $this->routes[$method][$route] = $action;
    }

    public function dispatch()
    {
        $method = $_SERVER['REQUEST_METHOD'];
        $uri = $this->normalizeRoute(parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH));

        if (strpos($uri, $this->basePath) === 0) {
            $routePath = substr($uri, strlen($this->basePath));
        } else {
            $routePath = $uri;
        }

        $routePathParts = explode("/", $routePath);
        $param = array_pop($routePathParts);
        $routePathPop = implode("/", $routePathParts) . "/{param}";


        if (isset($this->routes[$method][$routePath])) {

            $callable = $this->routes[$method][$routePath];

            call_user_func($callable);
        } else if (isset($this->routes[$method][$routePathPop])) {

            $callable = $this->routes[$method][$routePathPop];

            call_user_func($callable, $param);
        } else {
            ResponseHelper::sendResponse(404, ["message" => "Ruta no encontrada."]);
        }
    }

    private function normalizeRoute($route)
    {
        return trim($route, '/');
    }
}
